@@ -1,9 +1,11 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals, absolute_import
+from flask import __version__ as flask_version
 
 # Markdown is optional
 try:
     import markdown
+    from markdown.extensions.toc import TocExtension
 
     def apply_markdown(text):
         """
@@ -11,10 +13,15 @@ try:
         of '#' style headers to <h2>.
         """
 
-        extensions = ['headerid(level=2)']
-        safe_mode = False
-        md = markdown.Markdown(extensions=extensions, safe_mode=safe_mode)
+        extensions = [TocExtension(baselevel=2)]
+        md = markdown.Markdown(extensions=extensions)
         return md.convert(text)
 
-except ImportError:
+
+except ImportError:  # pragma: no cover - markdown installed for tests
     apply_markdown = None
+
+
+def is_flask_legacy():
+    v = flask_version.split(".")
+    return int(v[0]) == 0 and int(v[1]) < 11
