@@ -1,15 +1,18 @@
 # coding: utf8
 from __future__ import unicode_literals
 from flask import request, Response
-from flask._compat import text_type, string_types
+from flask._compat import text_type
 
 
 class APIResponse(Response):
+
+    api_return_types = (list, dict)
+
     def __init__(self, content=None, *args, **kwargs):
         super(APIResponse, self).__init__(None, *args, **kwargs)
 
         media_type = None
-        if isinstance(content, (list, dict, text_type, string_types)):
+        if isinstance(content, self.api_return_types) or content == '':
             renderer = request.accepted_renderer
             if content != '' or renderer.handles_empty_responses:
                 media_type = request.accepted_media_type
